Wraps calc_ede to compute social welfare before and after an
intervention and decomposes the welfare change into efficiency and equity
components.
Value
A named list with elements:
ede_baselineEDE health before intervention.
ede_postEDE health after intervention.
delta_edeChange in EDE (welfare gain).
efficiency_componentChange in mean health.
equity_componentChange in EDE minus change in mean.
Examples
pre <- c(60, 63, 66, 69, 72)
post <- c(61, 64, 66.5, 69.2, 72.1)
w <- rep(0.2, 5)
calc_social_welfare(pre, post, w, eta = 1)
#> $ede_baseline
#> [1] 65.8633
#>
#> $ede_post
#> [1] 66.44688
#>
#> $delta_ede
#> [1] 0.5835786
#>
#> $efficiency_component
#> [1] 0.56
#>
#> $equity_component
#> [1] 0.02357865
#>